"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VerificationService = void 0;
const core_1 = require("@ethereum-sourcify/core");
const Injector_1 = require("./Injector");
class VerificationService {
    constructor(fileService, logger) {
        this.findByAddress = async (address, chain, repository) => {
            // Try to find by address, return on success.
            let matches = [];
            try {
                matches = await this.fileService.findByAddress(address, chain, repository);
            }
            catch (err) {
                const msg = "Could not find file in repository";
                this.logger.info({
                    loc: '[POST:VERIFICATION_BY_ADDRESS_FAILED]',
                    address: address
                }, msg);
            }
            return matches;
        };
        this.inject = async (inputData, localChainUrl) => {
            // Injection
            //const injection: Promise<Match>;
            //const { repository, chain, addresses, files } = inputData;
            const injector = await Injector_1.Injector.createAsync({
                localChainUrl: localChainUrl,
                log: this.logger,
                infuraPID: process.env.INFURA_ID,
                repositoryPath: this.fileService.repositoryPath,
                fileService: this.fileService
            });
            return injector.inject(inputData);
            //TODO:
            // const exchange = "test";
            // const topic = "test";
            //const channel: ConfirmChannel = await MQ.createChannelAndExchange(exchange, topic);
            //MQ.publishToExchange(exchange, channel, "inputdata", JSON.stringify(inputData));
            // promises.push(injector.inject(inputData));
            //return injection;
            // // This is so we can have multiple parallel injections, logic still has to be completely implemented
            // Promise.all(promises).then((result) => {
            //     res.status(200).send({result});
            // }).catch(err => {
            //     next(err); // Just forward it to error middelware
            // })
        };
        this.logger = logger || core_1.Logger("VerificationService");
        this.fileService = fileService || new core_1.FileService("./repository");
    }
}
exports.VerificationService = VerificationService;
//# sourceMappingURL=VerificationService.js.map