import Web3 from 'web3';
import { StringMap } from '@ethereum-sourcify/core';
import * as bunyan from 'bunyan';
export interface RecompilationResult {
    bytecode: string;
    deployedBytecode: string;
    metadata: string;
}
export declare interface ReformattedMetadata {
    input: any;
    fileName: string;
    contractName: string;
}
/**
 * Checks if provided endpoint is online
 * @param {string} provider personal project ID from infura.io or real Ethereum node endpoint
 */
export declare function checkEndpoint(provider: string): Promise<void>;
/**
 * Wraps eth_getCode
 * @param {Web3}   web3    connected web3 instance
 * @param {string} address contract
 */
export declare function getBytecode(web3: Web3, address: string): Promise<string>;
/**
 * Compiles sources using version and settings specified in metadata
 * @param  {any}                          metadata
 * @param  {string[]}                     sources  solidity files
 * @return {Promise<RecompilationResult>}
 */
export declare function recompile(metadata: any, sources: StringMap, log: bunyan): Promise<RecompilationResult>;
/**
 * Removes post-fixed metadata from a bytecode string
 * (for partial bytecode match comparisons )
 * @param  {string} bytecode
 * @return {string}          bytecode minus metadata
 */
export declare function getBytecodeWithoutMetadata(bytecode: string): string;
/**
 * Fetches the requested version of the Solidity compiler (soljson).
 * First attempts to search locally; if that fails, falls back to downloading it.
 *
 * @param version the solc version to retrieve: the expected format is
 *
 * "[v]<major>.<minor>.<patch>+commit.<hash>"
 *
 * e.g.: "0.6.6+commit.6c089d02"
 *
 * defaults to "latest"
 *
 * @param log a logger to track the course of events
 *
 * @returns the requested solc instance
 */
export declare function getSolcJs(version: string, log: bunyan): Promise<any>;
